/**
 * Testing our CardLink component
 */

import { mount } from 'enzyme';
import React from 'react';
import CardLink from '../CardLink';
import BootstrapProvider from '../../BootstrapProvider';

const children = <h1> test </h1>;

const renderComponent = (props = {}) => mount(
  <CardLink {...props} />
);

const renderComponentUsingTheme = (props = {}) => mount(
  <BootstrapProvider>
    <CardLink {...props} />
  </BootstrapProvider>
);


describe('<CardLink />', () => {
  it('should render an <CardLink> tag without a theme', () => {
    const renderedComponent = renderComponent({
      children,
    });
    expect(renderedComponent.find('A').length).toBe(1);
  });
  it('should have children without a theme', () => {
    const renderedComponent = renderComponent({
      children,
    });
    expect(renderedComponent.contains(children)).toEqual(true);
  });
  it('should render an <CardLink> tag with a theme', () => {
    const renderedComponent = renderComponentUsingTheme({
      children,
    });
    expect(renderedComponent.find('CardLink').length).toBe(1);
  });

  it('should have children with a theme', () => {
    const renderedComponent = renderComponentUsingTheme({
      children,
    });
    expect(renderedComponent.contains(children)).toEqual(true);
  });
});
